dos plotting Options — PyProcar 6.2.1 documentation

Skip to main content
`Ctrl`+`K`

# dos plotting Options

## cmap

description:

  The colormap used for the plot.

value:

  jet

## colors

description:

  List of colors for the plot lines.

value:

  [‘red’, ‘green’, ‘blue’, ‘cyan’, ‘magenta’, ‘yellow’, ‘orange’, ‘purple’, ‘brown’, ‘navy’, ‘maroon’, ‘olive’]

## colorbar_title

description:

  Title of the colorbar.

value:

  Atomic Orbital Projections

## colorbar_title_size

description:

  Font size of the title of the colorbar.

value:

  15

## colorbar_title_padding

description:

  Padding of the title of the colorbar.

value:

  20

## colorbar_tick_labelsize

description:

  Size of the title of the colorbar ticks

value:

  10

## fermi_color

description:

  The color of the Fermi line.

value:

  black

## fermi_linestyle

description:

  The linestyle of the Fermi line.

value:

  dotted

## fermi_linewidth

description:

  The linewidth of the Fermi line.

value:

  1

## figure_size

description:

  The size of the figure (width, height) in inches.

value:

  [9, 6]

## font

description:

  The font style for the plot text.

value:

  Arial

## font_size

description:

  The size of the font used in the plot.

value:

  16

## grid

description:

  If true, a grid will be shown on the plot.

value:

  False

## grid_axis

description:

  Which axis (or both) the grid lines should be drawn on.

value:

  both

## grid_color

description:

  The color of the grid lines.

value:

  grey

## grid_linestyle

description:

  The linestyle of the grid lines.

value:

  solid

## grid_linewidth

description:

  The linewidth of the grid lines.

value:

  1

## grid_which

description:

  Which grid lines to draw (major, minor or both).

value:

  major

## legend

description:

  If true, a legend will be shown on the plot.

value:

  True

## linestyle

description:

  The linestyles for the plot lines.

value:

  [‘solid’, ‘dashed’]

## linewidth

description:

  The linewidths for the plot lines.

value:

  [1, 1]

## marker

description:

  The marker styles for the plot points.

value:

  [‘o’, ‘v’, ‘^’, ‘D’]

## markersize

description:

  The size of the markers for the plot points.

value:

  [0.2, 0.2]

## opacity

description:

  The opacities for the plot lines.

value:

  [1.0, 1.0]

## plot_bar

description:

  If true, a bar plot will be displayed.

value:

  True

## plot_color_bar

description:

  If true, a color bar will be shown on the plot.

value:

  True

## plot_total

description:

  If true, the total plot will be displayed.

value:

  True

## savefig

description:

  The file name to save the figure. If null, the figure will not be saved.

value:

  None

## spin_colors

description:

  The colors for the spin up and spin down lines.

value:

  [‘black’, ‘red’]

## spin_labels

description:

  The labels for the spin up and spin down.

value:

  [‘$\uparrow$’, ‘$\downarrow$’]

## title

description:

  The title for the plot. If null, no title will be displayed.

value:

  None

## verbose

description:

  If true, the program will print detailed information.

value:

  True

## weighted_color

description:

  If true, the color of the lines will be weighted.

value:

  True

## weighted_width

description:

  If true, the width of the lines will be weighted.

value:

  False

## clim

description:

  Value range to scale the colorbar

value:

  None

## stack_y_label

description:

  The label for the y-axis for stack mode

value:

  DOS

## x_label

description:

  The label for the x-axis.

value:

  None

## y_label

description:

  The label for the y-axis.

value:

  None

## dpi

description:

  The resolution in dots per inch. If ‘figure’, use the figure’s dpi value.

value:

  figure